@@ -2,42 +2,32 @@
 main app base class with context help for flow and app state changes
 ====================================================================
 
-The class :class:`HelpAppBase` provided by this
-namespace portion is extending your application
-with a context-sensitive help functionality.
+The class :class:`HelpAppBase` provided by this namespace portion is extending your application with a context-sensitive
+help functionality.
 
-The data-driven approach allows to add, edit and
-remove help texts without the need to change a
-single line of code. This gets achieved within
-:class:`HelpAppBase` by overriding the main app class methods
-:meth:`~ae.gui_app.MainAppBase.change_flow` and
-:meth:`~ae.gui_app.MainAppBase.change_app_state`.
+The data-driven approach allows to add, edit and remove help texts without the need to change a single line of code or
+to recompile your app. This gets achieved within :class:`HelpAppBase` by overriding the main app class methods
+:meth:`~ae.gui_app.MainAppBase.change_flow` and :meth:`~ae.gui_app.MainAppBase.change_app_state`.
 
-So for to add help support to the widgets of your app
-you only need to add/provide the help texts with a help id
-that is matching the value of the :attr:`help_id`
-attribute of the widget you need help for.
+So to add help support to the widgets of your app you only need to add/provide the help texts with a help id that is
+matching the value of the :attr:`help_id` attribute of the widget you need help for.
 
-Additionally you can provide a separate i18n translation
-message file for each of the supported languages for to
-make your help texts multi-lingual.
+Additionally you can provide a separate i18n translation message file for each of the supported languages to make your
+help texts multi-lingual.
 
 
 help layout implementation example
 ----------------------------------
 
-:class:`HelpAppBase` inherits from :class:`~ae.gui_app.MainAppBase`
-while still being independent from the used GUI framework/library.
+:class:`HelpAppBase` inherits from :class:`~ae.gui_app.MainAppBase` while still being independent from the used GUI
+framework/library.
 
 .. note::
-    The user interface for this help system has to be provided
-    externally on top of this module. It can either be implemented
-    directly in your app project or in a separate module.
+    The user interface for this help system has to be provided externally on top of this module. It can either be
+    implemented directly in your app project or in a separate framework-specific module.
 
-Use :class:`HelpAppBase` as base class of the GUI framework
-specific main application class and implement the
-abstract methods :meth:`~ae.gui_app.MainAppBase.init_app` and
-:meth:`~HelpAppBase.ensure_top_most_z_index`::
+Use :class:`HelpAppBase` as base class of the GUI framework specific main application class and implement the abstract
+methods :meth:`~ae.gui_app.MainAppBase.init_app` and :meth:`~HelpAppBase.ensure_top_most_z_index`::
 
     from ae.gui_help import HelpAppBase
 
@@ -51,101 +41,76 @@ abstract methods :meth:`~ae.gui_app.MainAppBase.init_app` and
             framework_method_to_push_widget_to_top_most(widget)
             ...
 
-For to activate the help mode the widget
-for to display the help texts have to be assigned to
-the attribute :attr:`~HelpAppBase.help_layout`::
+For to activate the help mode the widget to display the help texts have to be assigned to the property/attribute
+:attr:`~HelpAppBase.help_layout`::
 
     main_app.help_layout = HelpScreenContainerOrWindow()
 
-:attr:`~HelpAppBase.help_layout` is also used as a flag
-of the help mode activity. By assigning `None` to this
-attribute the help mode will be deactivated::
+The :attr:`~HelpAppBase.help_layout` property is also used as a flag of the help mode activity. By assigning `None` to
+this attribute the help mode will be deactivated::
 
     main_app.help_layout = None
 
-Use the attribute :attr:`~HelpAppBase.help_activator`
-for to provide and store a widget that allows the user
-to toggle the help mode activation. The
-:meth:`~HelpAppBase.help_display` is using
-it as fallback widget if no help target
-widget got found.
+Use the attribute :attr:`~HelpAppBase.help_activator` to provide and store a widget that allows the user to toggle the
+help mode activation. The :meth:`~HelpAppBase.help_display` is using it as fallback widget if no help target widget got
+found.
 
 .. hint::
-    An example implementation of an de-/activation
-    method is :meth:`~ae.kivy_app.KivyMainApp.help_activation_toggle`
+    An example implementation of an de-/activation method is :meth:`~ae.kivy_app.KivyMainApp.help_activation_toggle`
     situated in the :mod:`ae.kivy_app` namespace portion.
 
-    This more complete example is also demonstrating
-    the implementation and usage of the help activator
-    and layout widgets (in the classes
-    :class:`~ae.kivy_help.HelpBehavior`,
-    :class:`~ae.kivy_help.HelpToggler` and
+    This more complete example is also demonstrating the implementation and usage of the help activator and layout
+    widgets (in the classes :class:`~ae.kivy_help.HelpBehavior`, :class:`~ae.kivy_help.HelpToggler` and
     :class:`~ae.kivy_help.HelpLayout`).
 
 
 additional helper functions
 ---------------------------
 
-The helper functions :func:`anchor_points`, :func:`layout_ps_hints`,
-:func:`layout_x` and :func:`layout_y`, provided
-by this module, are providing a framework-independent calculation
-of the position and size of the help layout and the anchor.
+The helper functions :func:`anchor_points`, :func:`layout_ps_hints`, :func:`layout_x` and :func:`layout_y`, provided
+by this module, are providing a framework-independent calculation of the position and size of the help layout and the
+anchor.
 
 
 flow change context message id
 ------------------------------
 
-The message id for to identify the help texts for each flow
-button is composed by the :meth:`~HelpAppBase.help_flow_id`,
-using the prefix marker string defined by the module variable
-:data:`HELP_ID_PREFIX_FLOW` followed by
-the flow id of the flow widget.
+The message id to identify the help texts for each flow button is composed by the :meth:`~HelpAppBase.help_flow_id`,
+using the prefix marker string defined by the module variable :data:`HELP_ID_PREFIX_FLOW` followed by the flow id of the
+flow widget.
 
-For example the message id for a flow button with the
-flow action `'open'`, the object `'item'` and the (optional)
-flow key `'123456'` is resulting in the following help text
-message id::
+For example the message id for a flow button with the flow action `'open'`, the object `'item'` and the (optional)
+flow key `'123456'` is resulting in the following help text message id::
 
     'help_flow#open_item:123456'
 
-If there is no need for a detailed message id that is taking
-the flow key into account, then simply create a help text
+If there is no need for a detailed message id that is taking the flow key into account, then simply create a help text
 message id without the flow key.
 
-The method :meth:`~HelpAppBase.help_display` does first
-search for a message id including the flow key in the
-available help text files and if not found it will
-automatically fallback to use a message id without
-the flow key::
+The method :meth:`~HelpAppBase.help_display` does first search for a message id including the flow key in the available
+help text files and if not found it will automatically fallback to use a message id without the flow key::
 
     'help_flow#open_item'
 
 .. hint::
-    More information regarding the flow id you find in
-    the doc string of the module :mod:`ae.gui_app` in the
-    section :ref:`application flow`.
+    More information regarding the flow id you find in the doc string of the module :mod:`ae.gui_app` in the section
+    :ref:`application flow`.
 
 
 application state change context message id
 -------------------------------------------
 
-The message ids for app state change help texts are using
-the prefix marker string defined by the module variable
-:data:`HELP_ID_PREFIX_STATE`, followed by
-the name of the app state and are composed via the
+The message ids for app state change help texts are using the prefix marker string defined by the module variable
+:data:`HELP_ID_PREFIX_STATE`, followed by the name of the app state and are composed via the method
 :meth:`~HelpAppBase.help_app_state_id`.
 
 
 pluralize-able help texts
 -------------------------
 
-Each message id can optionally have several different
-help texts for their pluralization. For that
-simply add a `count` item to the `help_vars`
-property of the help target widget and then
-define a help text for the all the possible
-count cases in your message text file
-like shown in the following example::
+Each message id can optionally have several different help texts for their pluralization. For that simply add a `count`
+item to the `help_vars` property of the help target widget and then define a help text for the all the possible count
+cases in your message text file like shown in the following example::
 
     {
         'message_id': {
@@ -158,20 +123,15 @@ like shown in the following example::
        ...
     }
 
-The provided `count` value can also be
-included/displayed in the help text,
-like shown in the `'zero'` count case of
+The provided `count` value can also be included/displayed in the help text, like shown in the `'zero'` count case of
 the example.
 
 
 pre- and post-change help texts
 -------------------------------
 
-For to display a different help message before and
-after the change of the flow id or the app state
-define a message dict with the keys `''` (an empty
-string) and `'after'` like shown in the following
-example::
+For to display a different help message before and after the change of the flow id or the app state define a message
+dict with the keys `''` (an empty string) and `'after'` like shown in the following example::
 
     {
         'message_id': {
@@ -182,9 +142,8 @@ example::
     }
 
 
-If you want to move/change the help target to
-another widget after a change, then use instead of
-`'after'` the '`next_help_id'` message dict key::
+If you want to move/change the help target to another widget after a change, then use instead of `'after'` the
+'`next_help_id'` message dict key::
 
     {
         'message_id': {
@@ -194,37 +153,28 @@ another widget after a change, then use instead of
        ...
     }
 
-In this case the help target will automatically change
-to the widget specified by the flow id in the '`next_help_id'`
-key, if the user was tapping the second time on the
-first/initial help target widget.
+In this case the help target will automatically change to the widget specified by the flow id in the '`next_help_id'`
+key, if the user was tapping the second time on the first/initial help target widget.
 
 
 i18n help texts
 ---------------
 
-The displayed help messages related to the message id
-will automatically get translated into the default
-language of the current system/environment.
+The displayed help messages related to the message id will automatically get translated into the default language of the
+current system/environment.
 
-The declaration and association of message ids and
-their related help messages is done with the help of
-the namespace portion :mod:`ae.i18n`.
+The declaration and association of message ids and their related help messages is done with the help of the namespace
+portion :mod:`ae.i18n`.
 
 
 further examples
 ----------------
 
-More details on these and other features of this
-help system, e.g. the usage of
-f-strings in the help texts, is documented in the
-doc string of the :mod:`ae.i18n` module.
+More details on these and other features of this help system, e.g. the usage of f-strings in the help texts, is
+documented in the doc string of the :mod:`ae.i18n` module.
 
-A more complex example app demonstrating the features
-of this context help system can be found in the
-repository of the
+A more complex example app demonstrating the features of this context help system can be found in the repository of the
 `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`_.
-
 """
 from abc import abstractmethod, ABC
 from typing import Any, Dict, Optional, Tuple, Union
@@ -234,7 +184,7 @@ from ae.i18n import default_language, get_f_string, register_package_translation
 from ae.gui_app import FLOW_KEY_SEP, flow_action, id_of_flow, module_globals, MainAppBase       # type: ignore
 
 
-__version__ = '0.1.22'
+__version__ = '0.1.23'
 
 
 register_package_translations()
@@ -259,7 +209,7 @@ def anchor_points(radius: float, anchor_x: float, anchor_y: float, anchor_dir: s
 
                             .. note:
                                 the direction in the y axis got named increase for higher y values
-                                and `decrease` for lower y values for to support different coordinate
+                                and `decrease` for lower y values to support different coordinate
                                 systems of the GUI frameworks.
 
                                 For example in `kivy` the zero value of the y axis is at the bottom
@@ -376,7 +326,7 @@ class HelpAppBase(MainAppBase, ABC):
     help_activator: Any = None          #: help mode de-/activator button widget
     help_layout: Optional[Any] = None   #: container/popup/dropdown/window widget in active help mode else None
 
-    _next_help_id: str = ''             #: last app state or flow change for to show help text on help mode activation
+    _next_help_id: str = ''             #: last app state or flow change to show help text on help mode activation
 
     @abstractmethod
     def ensure_top_most_z_index(self, widget: Any):
@@ -427,7 +377,7 @@ class HelpAppBase(MainAppBase, ABC):
         :param help_vars:       locals (args/kwargs) of overwritten :meth:`~ae.gui_app.MainAppBase.change_flow` method.
 
                                 items passed to the help text renderer:
-                                    * `count`: optional number used for to render a pluralized help text
+                                    * `count`: optional number used to render a pluralized help text
                                       for this app state change.
 
         :param changed:         False before change of the app state, pass True if app state got just/already changed.
@@ -466,10 +416,10 @@ class HelpAppBase(MainAppBase, ABC):
         :param help_id:         help id to show help text for.
         :param help_vars:       variables used in the conversion of the f-string expression to a string.
                                 optional items passed to the help text renderer:
-                                * `count`: optional number used for to render a pluralized help text.
-                                * `self`: target widget for to show help text for.
+                                * `count`: optional number used to render a pluralized help text.
+                                * `self`: target widget to show help text for.
         :param key_suffix:      suffix to the key used if the translation is a dict.
-        :param must_have:       pass True for to display error help text and console output if no help text exists.
+        :param must_have:       pass True to display error help text and console output if no help text exists.
         :return:                True if help text got found and displayed.
         """
         has_trans, short_help_id = help_id_has_translation(help_id)
@@ -577,7 +527,7 @@ class HelpAppBase(MainAppBase, ABC):
     def help_widget(self, help_id: str, help_vars: Dict[str, Any]) -> Any:
         """ ensure/find help target widget via attribute name/value and extend :paramref:`~help_widget.help_vars`.
 
-        :param help_id:         widget.help_id attribute value for to detect widget and call stack locals.
+        :param help_id:         widget.help_id attribute value to detect widget and call stack locals.
         :param help_vars:       help env variables, to be extended with event activation stack frame locals
                                 and a 'self' key with the help target widget.
         :return:                found help target widget or self.help_activator if not found.
@@ -607,7 +557,7 @@ class HelpAppBase(MainAppBase, ABC):
         return wid
 
     def on_flow_popup_close(self, _flow_key: str, _popup_args: Dict[str, Any]) -> bool:
-        """ overwritten popup close handler of FlowPopup widget for to reset help widget/text. """
+        """ overwritten popup close handler of FlowPopup widget to reset help widget/text. """
         if self.help_layout and self.help_widget(self.displayed_help_id, dict()) is self.help_activator:
             self.help_display('', dict())
         return True
